@@ -9,8 +9,10 @@
 #   Copyright (C) 2001-2008, 2013-2014 Steve Hay.  All rights reserved.
 #
 # LICENCE
-#   You may distribute under the terms of either the GNU General Public License
-#   or the Artistic License, as specified in the LICENCE file.
+#   This module is free software; you can redistribute it and/or modify it under
+#   the same terms as Perl itself, i.e. under the terms of either the GNU
+#   General Public License or the Artistic License, as specified in the LICENCE
+#   file.
 #
 #===============================================================================
 
@@ -37,6 +39,8 @@ use Win32::WinError qw(
 );
 use XSLoader qw();
 
+## no critic (Subroutines::ProhibitSubroutinePrototypes)
+
 sub fsopen(*$$$);
 sub sopen(*$$$;$);
 sub new_fh();
@@ -117,7 +121,7 @@ BEGIN {
 
     Exporter::export_ok_tags(qw(retry));
     
-    $VERSION = '4.02';
+    $VERSION = '4.03';
 
     # Get the ERROR_SHARING_VIOLATION constant loaded now, otherwise loading it
     # later the first time that we test for an error can actually interfere with
@@ -177,8 +181,8 @@ sub AUTOLOAD {
 
     # Generate an in-line subroutine returning the required value.
     {
-        no strict 'refs';
-        *$AUTOLOAD = sub { return $value };
+    no strict 'refs'; ## no critic (TestingAndDebugging::ProhibitNoStrict)
+    *$AUTOLOAD = sub { return $value };
     }
 
     # Switch to the subroutine that we have just generated.
@@ -1324,7 +1328,7 @@ that is even leaner and meaner than using C<Symbol::gensym()>: the "First-Class
 Filehandle Trick".  It is described in an article by Mark-Jason Dominus called
 "Seven Useful Uses of Local", which first appeared in The Perl Journal and can
 also be found (at the time of writing) on his website at the URL
-F<http://perl.plover.com/local.html>.  It consists simply of the following:
+L<http://perl.plover.com/local.html>.  It consists simply of the following:
 
     my $fh = do { local *FH };
 
@@ -1521,24 +1525,31 @@ or failure.
 B<THIS IS AN INCOMPATIBLE CHANGE.  EXISTING SOFTWARE THAT USES THESE FUNCTIONS
 WILL NEED TO BE MODIFIED.>
 
+=head1 KNOWN BUGS
+
+I<None>.
+
 =head1 FEEDBACK
 
 Patches, bug reports, suggestions or any other feedback is welcome.
 
-Bugs can be reported on the CPAN Request Tracker at
-F<https://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-SharedFileOpen>.
+Patches can be sent as GitHub pull requests at
+L<https://github.com/steve-m-hay/Win32-SharedFileOpen/pulls>.
 
-Open bugs on the CPAN Request Tracker can be viewed at
-F<https://rt.cpan.org/Public/Dist/Display.html?Status=Active;Dist=Win32-SharedFileOpen>.
+Bug reports and suggestions can be made on the CPAN Request Tracker at
+L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-SharedFileOpen>.
+
+Currently active requests on the CPAN Request Tracker can be viewed at
+L<https://rt.cpan.org/Public/Dist/Display.html?Status=Active;Queue=Win32-SharedFileOpen>.
 
 Please test this distribution.  See CPAN Testers Reports at
-F<http://www.cpantesters.org/> for details of how to get involved.
+L<http://www.cpantesters.org/> for details of how to get involved.
 
 Previous test results on CPAN Testers Reports can be viewed at
-F<http://www.cpantesters.org/distro/W/Win32-SharedFileOpen.html>.
+L<http://www.cpantesters.org/distro/W/Win32-SharedFileOpen.html>.
 
 Please rate this distribution on CPAN Ratings at
-F<http://cpanratings.perl.org/rate/?distribution=Win32-SharedFileOpen>.
+L<http://cpanratings.perl.org/rate/?distribution=Win32-SharedFileOpen>.
 
 =head1 SEE ALSO
 
@@ -1579,13 +1590,14 @@ in the fsopen() function.
 The latest version of this module is available from CPAN (see
 L<perlmodlib/"CPAN"> for details) at
 
-F<https://metacpan.org/release/Win32-SharedFileOpen> or
+L<https://metacpan.org/release/Win32-SharedFileOpen> or
 
-F<http://search.cpan.org/dist/Win32-SharedFileOpen/> or
+L<http://www.cpan.org/authors/id/S/SH/SHAY/> or
 
-F<http://www.cpan.org/authors/id/S/SH/SHAY/> or
+L<http://www.cpan.org/modules/by-module/Win32/>.
 
-F<http://www.cpan.org/modules/by-module/Win32/>.
+The latest source code is available from GitHub at
+L<https://github.com/steve-m-hay/Win32-SharedFileOpen>.
 
 =head1 INSTALLATION
 
@@ -1593,11 +1605,11 @@ See the F<INSTALL> file.
 
 =head1 AUTHOR
 
-Steve Hay E<lt>shay@cpan.orgE<gt>
+Steve Hay E<lt>L<shay@cpan.org|mailto:shay@cpan.org>E<gt>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001-2008, 2013-2014 Steve Hay.  All rights reserved.
+Copyright (C) 2001-2008, 2013-2015 Steve Hay.  All rights reserved.
 
 =head1 LICENCE
 
@@ -1607,11 +1619,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 4.02
+Version 4.03
 
 =head1 DATE
 
-30 May 2014
+31 Jul 2018
 
 =head1 HISTORY
 
